==> nextcloud-app-mail-1.5.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/lt_LT.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "Automatinis nustatymų aptikimas nepavyko. Įveskite duomenis rankiniu būdu.",
    "Updating account failed: " : "Paskyros atnaujinimas nepavyko: ",
    "Creating account failed: " : "Paskyros sukūrimas nepavyko: ",
    "Embedded message %s" : "Įterptas laiškas %s",
    "Mails" : "El. laiškai",
    "Mail" : "Paštas",
    "💌 A mail app for Nextcloud" : "💌 Pašto programėlė, skirta Nextcloud",
    "Auto" : "Automatiškai",
    "Name" : "Vardas",
    "Mail Address" : "Elektroninio pašto adresas",
    "Password" : "Slaptažodis",
    "Manual" : "Rankiniu būdu",
    "IMAP Settings" : "IMAP nustatymai",
    "IMAP Host" : "IMAP serveris",
    "IMAP Security" : "IMAP saugumas",
    "None" : "Nėra",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP prievadas",
    "IMAP User" : "IMAP naudotojo vardas",
    "IMAP Password" : "IMAP slaptažodis",
    "SMTP Settings" : "SMTP nustatymai",
    "SMTP Host" : "SMTP serveris",
    "SMTP Security" : "SMTP saugumas",
    "SMTP Port" : "SMTP prievadas",
    "SMTP User" : "SMTP naudotojo vardas",
    "SMTP Password" : "SMTP slaptažodis",
    "Save" : "Įrašyti",
    "Connect" : "Prisijungti",
    "Add mail account" : "Pridėti pašto paskyrą",
    "Use Gravatar and favicon avatars" : "Naudoti Gravatar ir svetainių piktogramų avatarus",
    "Show keyboard shortcuts" : "Rodyti klaviatūros kombinacijas",
    "From" : "Nuo",
    "Select account" : "Pasirinkti paskyrą",
    "To" : "Kam",
    "Contact or email address …" : "Adresatas ar el. pašto adresas…",
    "+ Cc/Bcc" : "+ Cc/Bcc",
    "Cc" : "Cc",
    "No contacts found." : "Adresatų nerasta.",
    "Bcc" : "Bcc",
    "Subject" : "Tema",
    "Subject …" : "Tema…",
    "This message came from a noreply address so your reply will probably not be read." : "Šis laiškas atėjo iš adreso, kuris nėra skirtas atsakyti, taigi jūsų atsakymas, tikriausiai, nebus perskaitytas.",
    "Saving draft …" : "Įrašomas juodraštis …",
    "Draft saved" : "Juodraštis įrašytas",
    "Upload attachment" : "Įkelti priedą",
    "Add attachment from Files" : "Pridėti priedą iš Failų",
    "Enable formatting" : "Įjungti formatavimą",
    "Encrypt message with Mailvelope" : "Šifruoti laišką naudojant Mailvelope",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Ieškote būdo kaip šifruoti savo el. laiškus? Įsidiekite Mailvelope naršyklės plėtinį!",
    "Uploading attachments …" : "Įkeliami priedai …",
    "Sending …" : "Siunčiama …",
    "Error sending your message" : "Klaida siunčiant jūsų laišką",
    "Go back" : "Grįžti",
    "Retry" : "Bandyti dar kartą",
    "Message sent!" : "Laiškas išsiųstas!",
    "Write another message" : "Rašyti dar vieną laišką",
    "Send" : "Siųsti",
    "Encrypt and send" : "Šifruoti ir siųsti",
    "Send unencrypted" : "Siųsti nešifruotą",
    "Uploading {percent}% …" : "Įkeliama {percent}% …",
    "Choose a file to add as attachment" : "Pasirinkite failą, kurį prisegsite prie laiško",
    "Writing mode" : "Rašymo veiksena",
    "Plain text" : "Grynasis tekstas",
    "Rich text" : "Raiškusis tekstas",
    "No messages in this folder" : "Šiame aplankė pranešimų nėra",
    "Draft: " : "Juodraštis: ",
    "Mark unimportant" : "Žymėti kaip nesvarbų",
    "Mark important" : "Žymėti kaip svarbų",
    "Mark unread" : "Žymėti kaip neskaitytą",
    "Mark read" : "Žymėti kaip skaitytą",
    "Unselect" : "Nuimti žymėjimą",
    "Select" : "Pasirinkti",
    "Delete" : "Ištrinti",
    "Delete " : "Ištrinti ",
    "Load more" : "Įkelti daugiau",
    "Report this bug" : "Pranešti apie šią klaidą",
    "Could not open mailbox" : "Nepavyko atverti pašto dėžutės",
    "Loading messages" : "Įkeliami laiškai",
    "Important" : "Svarbios",
    "Favorites" : "Mėgstamos",
    "Other" : "Kita",
    "Attachments" : "Priedai",
    "Import into calendar" : "Importuoti į kalendorių",
    "Download attachment" : "Atsisiųsti priedą",
    "Save to Files" : "Įrašyti į Failus",
    "Unnamed" : "Be pavadinimo",
    "Embedded message" : "Įterptas laiškas",
    "Choose a folder to store the attachment in" : "Pasirinkite aplanką, kuriame išsaugoti priedą",
    "Save all to Files" : "Įrašyti visus į Failus",
    "Choose a folder to store the attachments in" : "Pasirinkite aplanką, kuriame laikyti priedus",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Šis laiškas yra šifruotas naudojant PGP. Norėdami jį iššifruoti, įsidiekite Mailvelope.",
    "The images have been blocked to protect your privacy." : "Tam, kad būtų apsaugotas jūsų privatumas, paveikslai buvo užblokuoti.",
    "Show images from this sender" : "Rodyti paveikslus nuo šio siuntėjo",
    "New message" : "Naujas laiškas",
    "Settings" : "Nustatymai",
    "Quota" : "Leidžiamas duomenų kiekis",
    "Account settings" : "Paskyros nustatymai",
    "Add folder" : "Pridėti aplanką",
    "Saving" : "Įrašoma",
    "Move up" : "Pakelti",
    "Move down" : "Nuleisti",
    "Remove account" : "Šalinti paskyrą",
    "Loading …" : "Įkeliama…",
    "Not supported by the server" : "Serveris nepalaiko",
    "{usage} of {limit} used" : "Panaudota {usage} iš {limit}",
    "Remove account {email}" : "Šalinti paskyrą {email}",
    "Remove {email}" : "Šalinti {email}",
    "Cancel" : "Atsisakyti",
    "Show all folders" : "Rodyti visus aplankus",
    "Collapse folders" : "Suskleisti aplankus",
    "Mark all as read" : "Žymėti visus kaip skaitytus",
    "Add subfolder" : "Pridėti poaplankį",
    "Edit name" : "Taisyti pavadinimą",
    "Clear cache" : "Išvalyti podėlį",
    "Delete folder" : "Ištrinti aplanką",
    "Delete folder {name}" : "Ištrinti aplanką {name}",
    "An error occurred, unable to rename the mailbox." : "Įvyko klaida, nepavyko pervadinti pašto dėžutės.",
    "_{total} message_::_{total} messages_" : ["{total} laiškas","{total} laiškai","{total} laiškų","{total} laiškas"],
    "Not found" : "Nerasta",
    "Could not load your draft" : "Nepavyko įkelti jūsų juodraščio",
    "Could not load original message" : "Nepavyko įkelti pradinio laiško",
    "Signature" : "Parašas",
    "A signature is added to the text of new messages and replies." : "Parašas yra pridedamas į naujų ir atsakomųjų laiškų tekstą.",
    "Signature …" : "Parašas…",
    "Save signature" : "Įrašyti parašą",
    "Reply" : "Atsakyti",
    "Reply to sender only" : "Atsakyti tik siuntėjui",
    "Forward" : "Persiųsti",
    "Import into {calendar}" : "Importuoti į {calendar}",
    "Event imported into {calendar}" : "Įvykis importuotas į {calendar}",
    "Could not create event" : "Nepavyko sukurti įvykio",
    "Airplane" : "Lėktuvas",
    "Reservation {id}" : "Rezervacija {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Skrydis {flightNr} iš {depAirport} į {arrAirport}",
    "Train" : "Traukinys",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iš {depStation} į {arrStation}",
    "Train from {depStation} to {arrStation}" : "Traukinys iš {depStation} į {arrStation}",
    "Mail app" : "Pašto programėlė",
    "The mail app allows users to read mails on their IMAP accounts." : "Pašto programėlė leidžia naudotojams skaityti laiškus savo IMAP paskyrose.",
    "Email: {email}" : "El. paštas: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} ties {host}:{port} ({ssl} šifravimas)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} ties {host}:{port} ({ssl} šifravimas)",
    "Provision an account for every user" : "Parūpinti paskyrą kiekvienam naudotojui",
    "General" : "Bendra",
    "Email address" : "El. pašto adresas",
    "IMAP" : "IMAP",
    "User" : "Naudotojas",
    "Host" : "Serveris",
    "Port" : "Prievadas",
    "SMTP" : "SMTP",
    "Apply and create/update for all users" : "Taikyti ir sukurti/atnaujinti visiems naudotojams",
    "Change name" : "Keisti vardą",
    "Mail server" : "Pašto serveris",
    "Keyboard shortcut" : "Spartusis klavišas",
    "Keyboard shortcuts" : "Klaviatūros greitieji klavišai",
    "Speed up your Mail experience with these quick shortcuts." : "Padidinkite savo našumą naudodamiesi šiomis nuorodomis.",
    "Compose new message" : "Rašyti naują laišką",
    "Newer message" : "Naujesni laiškai",
    "Older message" : "Senesni laiškai",
    "Toggle star" : "Perjungti laiško žymėjimą, kaip pažymėtą žvaigždute",
    "Toggle unread" : "Perjungti laiško žymėjimą, kaip neskaityto",
    "Search" : "Ieškoti",
    "Refresh" : "Įkelti iš naujo",
    "Connect your mail account" : "Priregistruoti elektroninio pašto paskyrą",
    "Unexpected error during account creation" : "Netikėta klaida kuriant paskyrą",
    "All" : "Visos",
    "Archive" : "Archyvuoti",
    "Drafts" : "Juodraščiai",
    "All inboxes" : "Visos pašto dėžutės",
    "Inbox" : "Gauta",
    "Junk" : "Šlamštas",
    "Sent" : "Išsiųsta",
    "Trash" : "Šiukšlinė",
    "Error while sharing file" : "Klaida bendrinant failą",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n naujas laiškas \nnuo {from}","%n nauji laiškai \nnuo {from}","%n naujų laiškų \nnuo {from}","%n naujų laiškų \nnuo {from}"],
    "Nextcloud Mail" : "Nextcloud el. paštas",
    "Could not load {tag}{name}{endtag}" : "Nepavyko įkelti {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Įvyko klaida bandant parodyti {tag}{name}{endtag}",
    "Could not load your message" : "Nepavyko įkelti jūsų laiško",
    "Could not load the desired message" : "Nepavyko įkelti pageidaujamo laiško",
    "Could not load the message" : "Nepavyko įkelti laiško",
    "Error loading message" : "Klaida, įkeliant laišką",
    "Forwarding to %s" : "Persiunčiama į %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Jeigu per artimiausias kelias sekundes nesate automatiškai nukreipiami, spustelėkite čia.",
    "Redirect" : "Peradresuoti",
    "The link leads to %s" : "Nuoroda veda į %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Jeigu jūs nenorite lankytis tame puslapyje, galite grįžti į <a href=\"%s\">Paštą</a>.",
    "Continue to %s" : "Tęsti į %s"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-app-mail-1.7.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/lt_LT.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "Automatinis nustatymų aptikimas nepavyko. Įveskite duomenis rankiniu būdu.",
    "Updating account failed: " : "Paskyros atnaujinimas nepavyko: ",
    "Creating account failed: " : "Paskyros sukūrimas nepavyko: ",
    "Embedded message %s" : "Įterptas laiškas %s",
    "Important mail" : "Svarbūs laiškai",
    "Mails" : "El. laiškai",
    "Mail" : "Paštas",
    "💌 A mail app for Nextcloud" : "💌 Pašto programėlė, skirta Nextcloud",
    "Draft messages are saved to:" : "Juodraščiai yra perkeliami į:",
    "Sent messages are saved to:" : "Išsiųsti laiškai yra perkeliami į:",
    "Deleted messages are moved to:" : "Ištrinti laiškai yra perkeliami į:",
    "Auto" : "Automatiškai",
    "Name" : "Vardas",
    "Mail Address" : "Elektroninio pašto adresas",
    "Password" : "Slaptažodis",
    "Manual" : "Rankiniu būdu",
    "IMAP Settings" : "IMAP nustatymai",
    "IMAP Host" : "IMAP serveris",
    "IMAP Security" : "IMAP saugumas",
    "None" : "Nėra",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP prievadas",
    "IMAP User" : "IMAP naudotojo vardas",
    "IMAP Password" : "IMAP slaptažodis",
    "SMTP Settings" : "SMTP nustatymai",
    "SMTP Host" : "SMTP serveris",
    "SMTP Security" : "SMTP saugumas",
    "SMTP Port" : "SMTP prievadas",
    "SMTP User" : "SMTP naudotojo vardas",
    "SMTP Password" : "SMTP slaptažodis",
    "Save" : "Įrašyti",
    "Connect" : "Prisijungti",
    "Add alias" : "Pridėti alternatyvų vardą",
    "Add mail account" : "Pridėti pašto paskyrą",
    "Use Gravatar and favicon avatars" : "Naudoti Gravatar ir svetainių piktogramų avatarus",
    "Register as application for mail links" : "Registruoti kaip pašto nuorodų programėlę",
    "Show keyboard shortcuts" : "Rodyti sparčiuosius klavišus",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Leisti programėlei rinkti duomenis apie jūsų sąveikas. Remiantis šiais duomenimis, programėlė prisitaikys prie jūsų nuostatų. Duomenys bus laikomi tik vietoje.",
    "From" : "Nuo",
    "Select account" : "Pasirinkti paskyrą",
    "To" : "Kam",
    "Contact or email address …" : "Adresatas ar el. pašto adresas…",
    "+ Cc/Bcc" : "+ Cc/Bcc",
    "Cc" : "Cc",
    "No contacts found." : "Adresatų nerasta.",
    "Bcc" : "Bcc",
    "Subject" : "Tema",
    "Subject …" : "Tema…",
    "This message came from a noreply address so your reply will probably not be read." : "Šis laiškas atėjo iš adreso, kuris nėra skirtas atsakyti, taigi jūsų atsakymas, tikriausiai, nebus perskaitytas.",
    "The following recipients do not have a PGP key: {recipients}." : "Šie gavėjai neturi PGP rakto: {recipients}.",
    "Write message …" : "Rašykite laišką…",
    "Saving draft …" : "Įrašomas juodraštis …",
    "Draft saved" : "Juodraštis įrašytas",
    "Upload attachment" : "Įkelti priedą",
    "Add attachment from Files" : "Pridėti priedą iš Failų",
    "Add attachment link from Files" : "Pridėti priedo nuorodą iš Failų",
    "Enable formatting" : "Įjungti formatavimą",
    "Encrypt message with Mailvelope" : "Šifruoti laišką naudojant Mailvelope",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Ieškote būdo kaip šifruoti savo el. laiškus? Įsidiekite Mailvelope naršyklės plėtinį!",
    "Uploading attachments …" : "Įkeliami priedai …",
    "Sending …" : "Siunčiama …",
    "Error sending your message" : "Klaida siunčiant jūsų laišką",
    "Go back" : "Grįžti",
    "Retry" : "Bandyti dar kartą",
    "Message sent!" : "Laiškas išsiųstas!",
    "Write another message" : "Rašyti dar vieną laišką",
    "Send" : "Siųsti",
    "Encrypt and send" : "Šifruoti ir siųsti",
    "Send unencrypted" : "Siųsti nešifruotą",
    "Uploading {percent}% …" : "Įkeliama {percent}% …",
    "Choose a file to add as attachment" : "Pasirinkite failą, kurį prisegsite prie laiško",
    "Choose a file to share as a link" : "Pasirinkite failą, kurį bendrinsite kaip nuorodą",
    "Writing mode" : "Rašymo veiksena",
    "Preferred writing mode for new messages and replies." : "Pageidaujama rašymo veiksena naujuose laiškuose ir atsakant į laiškus.",
    "Plain text" : "Grynasis tekstas",
    "Rich text" : "Raiškusis tekstas",
    "No messages in this folder" : "Šiame aplanke laiškų nėra",
    "No messages" : "Nėra laiškų",
    "Draft: " : "Juodraštis: ",
    "Mark unimportant" : "Žymėti kaip nesvarbų",
    "Mark important" : "Žymėti kaip svarbų",
    "Mark unfavorite" : "Žymėti kaip nebemėgstamą",
    "Mark favorite" : "Žymėti kaip mėgstamą",
    "Mark unread" : "Žymėti kaip neskaitytą",
    "Mark read" : "Žymėti kaip skaitytą",
    "Unselect" : "Nuimti žymėjimą",
    "Select" : "Pasirinkti",
    "Move" : "Perkelti",
    "Delete" : "Ištrinti",
    "Could not delete message" : "Nepavyko ištrinti laiško",
    "Mark {number} unread" : "Žymėti {number} kaip neskaitytus",
    "Mark {number} read" : "Žymėti {number} kaip skaitytus",
    "Move {number}" : "Perkelti {number}",
    "Delete {number}" : "Ištrinti {number}",
    "Load more" : "Įkelti daugiau",
    "Report this bug" : "Pranešti apie šią klaidą",
    "Could not open mailbox" : "Nepavyko atverti pašto dėžutės",
    "Loading messages" : "Įkeliami laiškai",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Indeksuojami jūsų laiškai. Didelėse pašto dėžutėse tai gali užtrukti šiek tiek ilgiau.",
    "Choose target folder" : "Pasirinkite paskirties aplanką",
    "No more subfolders in here" : "Čia daugiau nebėra poaplankių",
    "Choose" : "Pasirinkite",
    "Important" : "Svarbūs",
    "Important info" : "Svarbi informacija",
    "Favorites" : "Mėgstami",
    "Other" : "Kita",
    "Attachments" : "Priedai",
    "Import into calendar" : "Importuoti į kalendorių",
    "Download attachment" : "Atsisiųsti priedą",
    "Save to Files" : "Įrašyti į Failus",
    "Unnamed" : "Be pavadinimo",
    "Embedded message" : "Įterptas laiškas",
    "Choose a folder to store the attachment in" : "Pasirinkite aplanką, kuriame išsaugoti priedą",
    "Save all to Files" : "Įrašyti visus į Failus",
    "Choose a folder to store the attachments in" : "Pasirinkite aplanką, kuriame laikyti priedus",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Šis laiškas yra šifruotas naudojant PGP. Norėdami jį iššifruoti, įsidiekite Mailvelope.",
    "The images have been blocked to protect your privacy." : "Tam, kad būtų apsaugotas jūsų privatumas, paveikslai buvo užblokuoti.",
    "Show images from this sender" : "Rodyti paveikslus nuo šio siuntėjo",
    "New message" : "Naujas laiškas",
    "Settings" : "Nustatymai",
    "Quota" : "Leidžiamas duomenų kiekis",
    "Account settings" : "Paskyros nustatymai",
    "Show only subscribed folders" : "Rodyti tik prenumeruotus aplankus",
    "Add folder" : "Pridėti aplanką",
    "Saving" : "Įrašoma",
    "Move up" : "Pakelti",
    "Move down" : "Nuleisti",
    "Remove account" : "Šalinti paskyrą",
    "Loading …" : "Įkeliama…",
    "Not supported by the server" : "Serveris nepalaiko",
    "{usage} of {limit} used" : "Panaudota {usage} iš {limit}",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Paskyra {email} ir podėlyje esantys el. pašto duomenys bus pašalinti iš Nextcloud, tačiau nebus pašalinti iš jūsų el. pašto teikėjo puslapio.",
    "Remove account {email}" : "Šalinti paskyrą {email}",
    "Remove {email}" : "Šalinti {email}",
    "Cancel" : "Atsisakyti",
    "Show all subscribed folders" : "Rodyti visus prenumeruotus aplankus",
    "Show all folders" : "Rodyti visus aplankus",
    "Collapse folders" : "Suskleisti aplankus",
    "Mark all as read" : "Žymėti visus kaip skaitytus",
    "Mark all messages of this mailbox as read" : "Žymėti visus laiškus šioje pašto dėžutėje kaip skaitytus",
    "Add subfolder" : "Pridėti poaplankį",
    "Edit name" : "Taisyti pavadinimą",
    "Clear cache" : "Išvalyti podėlį",
    "Subscribed" : "Prenumeruotas",
    "Sync in background" : "Sinchronizuoti fone",
    "Delete folder" : "Ištrinti aplanką",
    "The folder and all messages in it will be deleted." : "Aplankas ir visi jame esantys laiškai bus ištrinti.",
    "Delete folder {name}" : "Ištrinti aplanką {name}",
    "An error occurred, unable to rename the mailbox." : "Įvyko klaida, nepavyko pervadinti pašto dėžutės.",
    "_{total} message_::_{total} messages_" : ["{total} laiškas","{total} laiškai","{total} laiškų","{total} laiškas"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} neskaitytas iš {total}","{unread} neskaityti iš {total}","{unread} neskaitytų iš {total}","{unread} neskaitytas iš {total}"],
    "Not found" : "Nerasta",
    "Could not load your draft" : "Nepavyko įkelti jūsų juodraščio",
    "Could not load original message" : "Nepavyko įkelti pradinio laiško",
    "No message selected" : "Nepasirinktas joks laiškas",
    "Signature" : "Parašas",
    "A signature is added to the text of new messages and replies." : "Parašas yra pridedamas į naujų ir atsakomųjų laiškų tekstą.",
    "Signature …" : "Parašas…",
    "Save signature" : "Įrašyti parašą",
    "Reply" : "Atsakyti",
    "Reply to sender only" : "Atsakyti tik siuntėjui",
    "Forward" : "Persiųsti",
    "Import into {calendar}" : "Importuoti į {calendar}",
    "Event imported into {calendar}" : "Įvykis importuotas į {calendar}",
    "Could not create event" : "Nepavyko sukurti įvykio",
    "Airplane" : "Lėktuvas",
    "Reservation {id}" : "Rezervacija {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Skrydis {flightNr} iš {depAirport} į {arrAirport}",
    "Train" : "Traukinys",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iš {depStation} į {arrStation}",
    "Train from {depStation} to {arrStation}" : "Traukinys iš {depStation} į {arrStation}",
    "Mail app" : "Pašto programėlė",
    "The mail app allows users to read mails on their IMAP accounts." : "Pašto programėlė leidžia naudotojams skaityti laiškus savo IMAP paskyrose.",
    "Email: {email}" : "El. paštas: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} ties {host}:{port} ({ssl} šifravimas)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} ties {host}:{port} ({ssl} šifravimas)",
    "Provision an account for every user" : "Parūpinti paskyrą kiekvienam naudotojui",
    "General" : "Bendra",
    "Email address" : "El. pašto adresas",
    "IMAP" : "IMAP",
    "User" : "Naudotojas",
    "Host" : "Serveris",
    "Port" : "Prievadas",
    "SMTP" : "SMTP",
    "Apply and create/update for all users" : "Taikyti ir sukurti/atnaujinti visiems naudotojams",
    "With the settings above, the app will create account settings in the following way:" : "Naudodama aukščiau esančius nustatymus, programėlė sukurs paskyrai nustatymus štai tokiu būdu: ",
    "Change name" : "Keisti vardą",
    "Mail server" : "Pašto serveris",
    "No message found yet" : "Kol kas nerasta jokių el. laiškų",
    "Set up an account" : "Nusistatyti paskyrą",
    "Keyboard shortcut" : "Spartusis klavišas",
    "Keyboard shortcuts" : "Klaviatūros greitieji klavišai",
    "Speed up your Mail experience with these quick shortcuts." : "Padidinkite savo našumą naudodamiesi šiomis nuorodomis.",
    "Compose new message" : "Rašyti naują laišką",
    "Newer message" : "Naujesni laiškai",
    "Older message" : "Senesni laiškai",
    "Toggle star" : "Perjungti laiško žymėjimą, kaip pažymėtą žvaigždute",
    "Toggle unread" : "Perjungti laiško žymėjimą, kaip neskaityto",
    "Search" : "Ieškoti",
    "Refresh" : "Įkelti iš naujo",
    "Connect your mail account" : "Priregistruoti elektroninio pašto paskyrą",
    "Unexpected error during account creation" : "Netikėta klaida kuriant paskyrą",
    "All" : "Visos",
    "Archive" : "Archyvuoti",
    "Drafts" : "Juodraščiai",
    "All inboxes" : "Visos pašto dėžutės",
    "Inbox" : "Gauta",
    "Junk" : "Šlamštas",
    "Sent" : "Išsiųsta",
    "Trash" : "Šiukšlinė",
    "Error while sharing file" : "Klaida bendrinant failą",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n naujas laiškas \nnuo {from}","%n nauji laiškai \nnuo {from}","%n naujų laiškų \nnuo {from}","%n naujų laiškų \nnuo {from}"],
    "Nextcloud Mail" : "Nextcloud el. paštas",
    "Could not load {tag}{name}{endtag}" : "Nepavyko įkelti {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Įvyko klaida bandant parodyti {tag}{name}{endtag}",
    "Could not load your message" : "Nepavyko įkelti jūsų laiško",
    "Could not load the desired message" : "Nepavyko įkelti pageidaujamo laiško",
    "Could not load the message" : "Nepavyko įkelti laiško",
    "Error loading message" : "Klaida, įkeliant laišką",
    "Forwarding to %s" : "Persiunčiama į %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Jeigu per artimiausias kelias sekundes nesate automatiškai nukreipiami, spustelėkite čia.",
    "Redirect" : "Peradresuoti",
    "The link leads to %s" : "Nuoroda veda į %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Jeigu jūs nenorite lankytis tame puslapyje, galite grįžti į <a href=\"%s\">Paštą</a>.",
    "Continue to %s" : "Tęsti į %s"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
